AndroidParams class

Object config for Android.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AndroidParams({bool? isCustomNotification, bool? isCustomSmallExNotification, bool? isShowCallback, bool? isShowMissedCallNotification, String? ringtonePath, String? backgroundColor, String? backgroundUrl, String? actionColor, String? incomingCallNotificationChannelName, String? missedCallNotificationChannelName})
const
AndroidParams.fromJson(Map<String, dynamic> json)
factory

Properties

actionColor → String?
Color used in button/text on notification.
final
backgroundColor → String?
Incoming call screen background color.
final
backgroundUrl → String?
Using image background for Incoming call screen. example: http://... https://... or "assets/abc.png"
final
hashCode → int
The hash code for this object.
no setterinherited
incomingCallNotificationChannelName → String?
Notification channel name of incoming call.
final
isCustomNotification → bool?
Using custom notifications.
final
isCustomSmallExNotification → bool?
Using custom notification small on some devices clipped out in android.
final
isShowCallback → bool?
Show callback action from miss call notification.
final
Show logo app inside full screen.
final
isShowMissedCallNotification → bool?
Show missed call notification when timeout
final
missedCallNotificationChannelName → String?
Notification channel name of missed call.
final
ringtonePath → String?
File name ringtone, put file into /android/app/src/main/res/raw/ringtone_default.pm3 -> value: ringtone_default.pm3
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited