CallKitParams class

Object config for General.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CallKitParams({String? id, String? nameCaller, String? appName, String? avatar, String? handle, double? type, double? duration, String? textAccept, String? textDecline, String? textMissedCall, String? textCallback, Map<String, dynamic>? extra, Map<String, dynamic>? headers, AndroidParams? android, IOSParams? ios})
const
CallKitParams.fromJson(Map<String, dynamic> json)
factory

Properties

android → AndroidParams?
final
appName → String?
final
avatar → String?
final
duration → double?
final
extra → Map<String, dynamic>?
final
handle → String?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, dynamic>?
final
id → String?
final
ios → IOSParams?
final
nameCaller → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAccept → String?
final
textCallback → String?
final
textDecline → String?
final
textMissedCall → String?
final
type → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited